@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = "0.1.2"
+
+import argparse
+
+__version__ = "0.2.0"
 
 
 CARD_URL    = 'https://bas.surf/terminalcard'
@@ -34,19 +37,29 @@ def get_card():
         pass
 
 
-def open_webbrowser():
+def open_webbrowser(url):
     try:
         import webbrowser
-        webbrowser.open(BROWSER_URL)
+        webbrowser.open(url)
     except:
         pass
 
 
 def main(show_card=True, open_browser=True):
+    parser = argparse.ArgumentParser(description='Display card and Short URL')
+    parser.add_argument('shurl', metavar='short-url', type=str, nargs='?',
+                        help='A bas.surf short url')
+    args = parser.parse_args()
+    try:
+        shurl = args.shurl
+        assert shurl
+        shurl = f"https://bas.surf/{shurl}"
+    except:
+        shurl = BROWSER_URL
     if show_card:
         print(get_card())
     if open_browser:
-        open_webbrowser()
+        open_webbrowser(shurl)
 
 
 if __name__ == '__main__':
